/*
 * Sort vector A[] and notice that visitors will consume exhibits alternating from A[]
 * extremes until someone stops them. Then, decompose the solution starting from a certain
 * exhibit E in what happens before and after the exhibits preceding E are consumed.
 *
 * The solution for what happens in a suffix (after) can be directly computed, as it does
 * not depend on the E chosen.
 *
 * The solution for what happens in a prefix (before) can be computed as a function f(x) of
 * what happens later (x), of the form f(x) = max(lower_bound, min(x, upper_bound)).
 * Furthermore, if the value A[E] is subtracted from f(x), this function does not depend on E.
 * Thus, we can compute the lower and upper bounds for every prefix directly.
 *
 * The final value is then: max(lower_bound[E]+A[E], min(suffix[E], upper_bound[E]+A[E])).
 */

#include <stdio.h>
#include <assert.h>
#include <algorithm>
#include <vector>

// constraints
#define MAXN 1000000
#define INF 1000000000000000L
#define MAX 0
#define MIN 1

using namespace std;

// input data
int N, M, i;
long long A[MAXN];
vector<pair<long long, int>> AP;
int E[MAXN];
long long lo[2][MAXN]; // lower limit for solution using first i items per end, starting with MAX/MIN
long long hi[2][MAXN]; // upper limit for solution using first i items per end, starting with MAX/MIN
long long sf[2][MAXN]; // solution of the suffix after the first i items per end, starting with MAX/MIN


long long minsuffix(int i, long long sum) {
    long long res = sum;
    if (N == 2*i) res = sum;
    else if (N == 2*i+1) {
        sf[MIN][i] = sum+A[i];
        res = min(sum, sf[MIN][i]);
    }
    else res = min( sum, max( sum+A[i], minsuffix(i+1, sum+A[i]+A[N-1-i]) ));
    if (i==0) return res;
    return sf[MIN][i-1] = sf[MIN][N-i] = res;
}

long long maxsuffix(int i, long long sum) {
    long long res = sum;
    if (N == 2*i) res = sum;
    else if (N == 2*i+1) {
        sf[MAX][i] = sum+A[N-1-i];
        res = max(sum, sf[MAX][i]);
    }
    else res = max( sum, min( sum+A[N-1-i], maxsuffix(i+1, sum+A[i]+A[N-1-i]) ));
    if (i==0) return res;
    return sf[MAX][i-1] = sf[MAX][N-i] = res;
}

void minbounds() {
    lo[MIN][0] = lo[MIN][N-1] = -INF;
    hi[MIN][0] = hi[MIN][N-1] = 0;
    long long sum = 0;
    for (i=0; i<=N-3-i; i++) {
        lo[MIN][i+1] = lo[MIN][N-i-2] = max(lo[MIN][i], min(hi[MIN][i], sum + A[i]));
        hi[MIN][i+1] = hi[MIN][N-i-2] = min(hi[MIN][i], max(lo[MIN][i], max(sum + A[i] + A[N-1-i], sum + A[i])));
        sum += A[i] + A[N-1-i];
    }
}

void maxbounds() {
    lo[MAX][0] = lo[MAX][N-1] = 0;
    hi[MAX][0] = hi[MAX][N-1] = INF;
    long long sum = 0;
    for (i=0; i<=N-3-i; i++) {
        lo[MAX][i+1] = lo[MAX][N-i-2] = max(lo[MAX][i], min(hi[MAX][i], min(sum + A[i] + A[N-1-i], sum + A[N-1-i])));
        hi[MAX][i+1] = hi[MAX][N-i-2] = min(hi[MAX][i], max(lo[MAX][i], sum + A[N-1-i]));
        sum += A[i] + A[N-1-i];
    }
}

int main() {
//  uncomment the following lines if you want to read/write from files
//  freopen("input.txt", "r", stdin);
//  freopen("output.txt", "w", stdout);

    assert(2 == scanf("%d %d", &N, &M));
    for (i=0; i<N; i++) {
        assert(1 == scanf("%lld", &A[i]));
        AP.emplace_back(A[i], i);
    }
    for (i=0; i<M; i++)
        assert(1 == scanf("%d", &E[i]));

    sort(AP.begin(), AP.end());
    for (i=0; i<N; i++) A[AP[i].second] = i;
    for (i=0; i<M; i++) E[i] = A[E[i]];
    for (i=0; i<N; i++) A[i] = AP[i].first;
    minsuffix(0, 0);
    maxsuffix(0, 0);
    minbounds();
    maxbounds();
    for (i=0; i<M; i++) {
        if (A[E[i]] > 0)
            printf("%lld ", max(lo[MIN][E[i]]+A[E[i]], min(sf[MAX][E[i]], hi[MIN][E[i]]+A[E[i]])));
        else
            printf("%lld ", max(lo[MAX][E[i]]+A[E[i]], min(sf[MIN][E[i]], hi[MAX][E[i]]+A[E[i]])));
    }
    printf("\n");
    return 0;
}
